@@ -111,17 +111,17 @@ class CommonGeometry:
         assert mesh_type in ["Progression", "Bulk"]
         self._TRANSFINITE_CURVE_QUEUE.append((curve._id, num_nodes, mesh_type, coeff))
 
-    def set_transfinite_surface(self, surface, arrangement, corner_tags):
+    def set_transfinite_surface(self, surface, arrangement, corner_pts):
+        corner_tags = [pt._id for pt in corner_pts]
         self._TRANSFINITE_SURFACE_QUEUE.append((surface._id, arrangement, corner_tags))
 
-    def set_transfinite_volume(self, volume, arrangement, corner_tags):
+    def set_transfinite_volume(self, volume, arrangement, corner_pts):
+        corner_tags = [pt._id for pt in corner_pts]
         self._TRANSFINITE_VOLUME_QUEUE.append((volume._id, corner_tags))
 
     def set_recombined_surfaces(self, surfaces):
         for i, surface in enumerate(surfaces):
-            assert isinstance(
-                surface, (PlaneSurface, Surface)
-            ), f"item {i} is not a surface"
+            assert surface.dim == 2, f"item {i} is not a surface"
         self._RECOMBINE_ENTITIES += [s.dim_tags[0] for s in surfaces]
 
     def extrude(
@@ -279,11 +279,11 @@ class CommonGeometry:
 
     def generate_mesh(  # noqa: C901
         self,
-        dim=3,
-        order=None,
+        dim: int = 3,
+        order: Optional[int] = None,
         # http://gmsh.info/doc/texinfo/gmsh.html#index-Mesh_002eAlgorithm
-        algorithm=None,
-        verbose=False,
+        algorithm: Optional[int] = None,
+        verbose: bool = False,
     ):
         """Return a meshio.Mesh, storing the mesh points, cells, and data, generated by
         Gmsh from the `self`.
